<?php

namespace Event\Event\Workflow;

use Event\Event\Models\Prize;
use Validator;

class PrizeValidator
{

    /**
     * Determine if the given prize is valid for complete status.
     *
     * @param Prize $prize
     *
     * @return bool / Validator
     */
    public function complete(Prize $prize)
    {
        return Validator::make($prize->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given prize is valid for verify status.
     *
     * @param Prize $prize
     *
     * @return bool / Validator
     */
    public function verify(Prize $prize)
    {
        return Validator::make($prize->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given prize is valid for approve status.
     *
     * @param Prize $prize
     *
     * @return bool / Validator
     */
    public function approve(Prize $prize)
    {
        return Validator::make($prize->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given prize is valid for publish status.
     *
     * @param Prize $prize
     *
     * @return bool / Validator
     */
    public function publish(Prize $prize)
    {
        return Validator::make($prize->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given prize is valid for archive status.
     *
     * @param Prize $prize
     *
     * @return bool / Validator
     */
    public function archive(Prize $prize)
    {
        return Validator::make($prize->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given prize is valid for unpublish status.
     *
     * @param Prize $prize
     *
     * @return bool / Validator
     */
    public function unpublish(Prize $prize)
    {
        return Validator::make($prize->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
